---
id: 403
properties:
- id: author
  name: Author
  type: string
  value: James Clear
- id: genre
  name: Genre
  type: string
  value: ''
- id: read
  name: Read
  type: boolean
  value: false
---

# Atomic Habits

Heard great things about the habit stacking technique. Want to read this next.